from pyvstress import SoilLayer, SoilProfile
import pyvstress.utility_functions as utf

# Description: Tests the generation of regular points for vertical stress


def generate_regular_points(soil_profile, analysis_type="vertical", dz=0.5):
    """Generate a list of points within the soil profile layer.

    Generate points, when possible, at equal intervals of dz.
    Points may not be dz apart near layer boundaries. Either one or two points
    are generated at internal layer boundaries based on whether the type of
    analysis involves vertical stresses, 1 point per boundary, or lateral stresses
    2 points per boundary, one point for the layer above the layer boundary and one
    point for the layer below the boundary.

    :param SoilProfile soilprofile: SoilProfile object
    :param float dz: maximum separation distance between points
    :param str analysis_type: type of analysis either 'vertical' or 'lateral'
    :returns: a list of Point objects, almost equally spaced over the soil profile
    :rtype: [Point]
    """

    # generate boundary points
    ptb = utf.stress_profile_points(soil_profile, analysis_type)
    return ptb


def main():
    # testing: vertical stresses
    # watertable: on the surface

    # soillayers
    layer1 = SoilLayer(5, 110, 120, phi=26, c=100)
    layer2 = SoilLayer(7, 115, 125, phi=28, c=100)
    layer3 = SoilLayer(4, 115, 122, phi=30, c=0)
    layer4 = SoilLayer(1, 112, 120, phi=25, c=25)
    layer5 = SoilLayer(10, 125, 135, phi=35, c=0)
    layers = [layer1, layer2, layer3, layer4, layer5]

    # soil profile
    soilprofile = SoilProfile(layers, zw=1.5, q=0, gammaw=62.4)
    ptb = generate_regular_points(soilprofile, "lateral", dz=0.5)

    for layer in soilprofile:
        print(layer)
    
    # for pt in ptb:
    #     print(pt)

    
    # dz = 0.5
    # depth = soilprofile.zbots[-1]
    # drem = depth % 10

    # if drem > 0:
    #     depth = math.floor(depth)
    #     print("here-1")
    # else:
    #     depth = math.floor(depth)
    #     print("here-2")

    # npts = int(depth/dz) + 1
    # pti = [i for i in np.linspace(0, depth, npts)]
    # pts = list(set(pts).union(set(pti)))
    # pts.sort()
    # print(f"pts: {pts}")
    # print(f"pti: {pti}")
    # print(f"pt: {pts}")
    # # print(bti)


if __name__ == "__main__":
    main()
